@@ -135,7 +135,7 @@ sub handle_add_remove ($$)
 
 	$entries_tmp = $entries . ".tmp";
 
-	my $tag;
+	my $tag = "";
 	my $tagfile = $file;
 	$tagfile =~ s{^(([^ ]+/)?)([^/ ]+)$}{${1}CVS/Tag};
 	if ($cmd_add && -f $tagfile) {
@@ -207,7 +207,9 @@ sub handle_added ($)
 	my $file = shift(@_);
 	open(DIFFOUT, "diff -u -L /dev/null -L $file /dev/null $file |") ||
 		error ("Cannot read output of diff: $!");
-	unix_print ("Index: $file");
+	unless (eof(DIFFOUT)) {
+		unix_print ("Index: $file");
+	}
 	while (<DIFFOUT>) {
 		unix_print ($_);
 	}
@@ -288,13 +290,15 @@ sub handle_modified ($)
 
 	my $diff_opts = "-u";
 	if ($short_file eq "ChangeLog") {
-		$diff_opts = "-u1";
+		$diff_opts = "-U 1";
 	}
 
 	open(DIFFOUT,
 	     "diff $diff_opts -L $file -L $file $backup_file $file |") ||
 		error ("Cannot read output of diff: $!");
-	unix_print ("Index: $file");
+	unless (eof(DIFFOUT)) {
+		unix_print ("Index: $file");
+	}
 	while (<DIFFOUT>) {
 		unix_print ($_);
 	}
